@@ -36,6 +36,7 @@ RUNNING = True
 SPEED = 40 # controls vehicle speed
 TIME = 0.2
 ENABLE_BUTTON = True # onboard yellow cap switch
+ENABLE_SONIC2 = True # 超声2 and BACK Collision share GPIO 13 and 26
 
 # 四轮驱动
 
@@ -58,6 +59,11 @@ colors = [0x010000, 0x001000]
 TRIG = 20
 ECHO = 21
 
+# 超声2
+
+TRIG2 = 13
+ECHO2 = 26
+
 # Fall detection. Use the three bottom tracking sensors. 
 # BOTTOM_RIGHT = 26 # change to back collision sensor
 BOTTOM_MIDDLE = 19 # use the yellow cap to swtich between button or this sensor
@@ -140,7 +146,9 @@ def keyscan():
 
     val = GPIO.input(BtnPin)
     while GPIO.input(BtnPin) == False:  # wait for press       
-        val = GPIO.input(BtnPin)
+        # val = GPIO.input(BtnPin)
+        print('front detection: ', front_detection())
+        print('back detection: ', back_detection())
 
     time.sleep(0.1) # after start, set green light on and red off
 
@@ -185,8 +193,13 @@ def setup():
     # collision detection
     GPIO.setup(SHORT_RANGE_LEFT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
     GPIO.setup(SHORT_RANGE_RIGHT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
-    GPIO.setup(SHORT_RANGE_BACK_LEFT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
-    GPIO.setup(SHORT_RANGE_BACK_RIGHT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
+
+    if ENABLE_SONIC2 == False:
+        GPIO.setup(SHORT_RANGE_BACK_LEFT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
+        GPIO.setup(SHORT_RANGE_BACK_RIGHT,GPIO.IN, pull_up_down=GPIO.PUD_UP)
+    else:
+        GPIO.setup(TRIG2, GPIO.OUT)
+        GPIO.setup(ECHO2, GPIO.IN)
     
     GPIO.setup(AIN2,GPIO.OUT)
     GPIO.setup(AIN1,GPIO.OUT)
@@ -207,19 +220,18 @@ def setup():
     # print( collision_detection() )    
     print_used_pins()
 
-def distance():
+def distance(pin_trig = TRIG, pin_echo = ECHO):
 
-    GPIO.output(TRIG, 0)
+    GPIO.output(pin_trig, 0)
     time.sleep(0.000002)
-
-    GPIO.output(TRIG, 1)
+    GPIO.output(pin_trig, 1)
     time.sleep(0.00001)
-    GPIO.output(TRIG, 0)
+    GPIO.output(pin_trig, 0)
     
-    while GPIO.input(ECHO) == 0:
+    while GPIO.input(pin_echo) == 0:
         a = 0
     time1 = time.time()
-    while GPIO.input(ECHO) == 1:
+    while GPIO.input(pin_echo) == 1:
         a = 1
     time2 = time.time()
 
@@ -234,10 +246,11 @@ def front_detection():
     return dis_f
 
 def back_detection():
+
     servo.turn_direction(3,90)
     time.sleep(0.5)
-    # dis_b = distance_back() # need to wire ultrsound
-    # return dis_b
+    dis_b = distance(TRIG2, ECHO2) # need to wire ultrsound
+    return dis_b
 
 def left_detection():
     servo.turn_direction(0, 170)
@@ -270,7 +283,7 @@ def collision_detection(disable_back_sensors = True, verbose = False):
 
     c_left, c_right = not GPIO.input(SHORT_RANGE_LEFT), not GPIO.input(SHORT_RANGE_RIGHT) # right seems opposite # these two sensors are in the front
     
-    if disable_back_sensors:
+    if ENABLE_SONIC2:
         c_back_left, c_back_right = False, False 
     else:
         c_back_left, c_back_right = not GPIO.input(SHORT_RANGE_BACK_LEFT), not GPIO.input(SHORT_RANGE_BACK_RIGHT) # these two sensors are in the back
